module TypeClassification

use GlobalVariables

implicit none

contains
! subroutine MountainsNotHabitable  -> used in MAIN
! subroutine MountainsHabitable     -> used in MAIN


subroutine MountainsNotHabitable
    ! Identifies the habitable nodes: type 1 (land) and 3 (coast), and non-habitable nodes
    ! Identifies coastal nodes
    !
    ! Saves the number of habitable nodes in numHabitableNodes
    ! Saves the id's of the habitable nodes in the array habitableNodes 
    ! Saves the number of coastal nodes in numCoastNodes
    ! Saves the id's of the coastal nodes in an array coastNodes
    !
    ! Saves the number of non-habitable nodes in numNonHabitableNodes
    ! Saves the id's of the habitable nodes in the array nonHabitableNodes 
    !
    ! Used in MAIN
    
    implicit none
    integer(4), dimension(numNodes) :: Array1, Array2, ArrayCoast

    numHabitableNodes = 0
    numNonHabitableNodes = 0
    numCoastNodes = 0
    
    do i_node = 1, numNodes  !scan all nodes
        
        if (Nodes(i_node)%node_type == 1) then !land nodes
            numHabitableNodes = numHabitableNodes + 1  !count the number of habitable nodes
            Array1(numHabitableNodes) = i_node  !save the node location in the array
        
        else if (Nodes(i_node)%node_type == 3) then  !coast nodes
            numHabitableNodes = numHabitableNodes + 1  !count the number of habitable nodes
            Array1(numHabitableNodes) = i_node  !save the node location in the array
            numCoastNodes = numCoastNodes + 1  !count the number of coastal nodes
            ArrayCoast(numCoastNodes) = i_node  !copy the coastal nodes location in the Nodes array
        
        else  !sea and mountain nodes
            numNonHabitableNodes = numNonHabitableNodes + 1  !count the number of non-habitable nodes
            Array2(numNonHabitableNodes) = i_node  !save the node location in the array
        endif
    enddo
    allocate(habitableNodes(numHabitableNodes))
    habitableNodes = Array1(:numHabitableNodes)  !to reduce space use we save the nodes in an shorter array
    allocate(nonHabitableNodes(numNonHabitableNodes))
    nonHabitableNodes = Array2(:numNonHabitableNodes)  !to reduce space use we save the nodes in an shorter array
    allocate(coastNodes(numCoastNodes))
    coastNodes = ArrayCoast(:numCoastNodes)  !to reduce space use we save the nodes in an shorter array

end subroutine MountainsNotHabitable


subroutine MountainsHabitable
    ! Identifies the habitable nodes: type 1 (land), mountains (2) and 3 (coast); and the non-habitable
    !       Here the mountain effect is ignored and mountain nodes are habitable
    !
    ! Changes the mountain type (2) into land type (1)  <===  !!!
    !
    ! Saves the number of habitable nodes in numHabitableNodes
    ! Saves the id's of the habitable nodes in the array habitableNodes 
    !
    ! Saves the number of non-habitable nodes in numNonHabitableNodes
    ! Saves the id's of the habitable nodes in the array nonHabitableNodes 
    !
    ! Used in MAIN

    implicit none
    integer(4), dimension(numNodes) :: Array1, Array2, ArrayCoast

    numHabitableNodes = 0
    numNonHabitableNodes = 0
    numCoastNodes = 0
    
    do i_node = 1, numNodes  !scan all nodes
        if (Nodes(i_node)%node_type == 1) then !land nodes
            numHabitableNodes = numHabitableNodes + 1  !count the number of habitable nodes
            Array1(numHabitableNodes) = i_node  !save the node location in the array
            
        else if (Nodes(i_node)%node_type == 2) then  !mountain nodes
            Nodes(i_node)%node_type = 1
            numHabitableNodes = numHabitableNodes + 1  !count the number of habitable nodes
            Array1(numHabitableNodes) = i_node  !save the node location in the array
        
        else if (Nodes(i_node)%node_type == 3) then  !coast nodes
            numHabitableNodes = numHabitableNodes + 1  !count the number of habitable nodes
            Array1(numHabitableNodes) = i_node  !save the node location in the array
            numCoastNodes = numCoastNodes + 1  !count the number of coastal nodes
            ArrayCoast(numCoastNodes) = i_node  !copy the coastal nodes location in the Nodes array
            
        else  !sea nodes
            numNonHabitableNodes = numNonHabitableNodes + 1  !count the number of non-habitable nodes
            Array2(numNonHabitableNodes) = i_node  !save the node location in the array
        endif
    enddo
    
    allocate(habitableNodes(numHabitableNodes))
    habitableNodes = Array1(:numHabitableNodes)  !to reduce space use we save the nodes in an shorter array
    allocate(nonHabitableNodes(numNonHabitableNodes))
    nonHabitableNodes = Array2(:numNonHabitableNodes)  !to reduce space use we save the nodes in an shorter array
    allocate(coastNodes(numCoastNodes))
    coastNodes = ArrayCoast(:numCoastNodes)  !to reduce space use we save the nodes in an shorter array

end subroutine MountainsHabitable



end module TypeClassification